@@ -1,24 +1,3 @@
-#' enaAll --- Conduct all ecological network analyses
-#' INPUT = network object
-#' OUTPUT = list of analytical output
-#' 
-#' M. Lau | May 2013
-#' ---------------------------------------------------
-
-
-
-
-
-
-
-#' enaAll --- Conduct all ecological network analyses INPUT = network object
-#' OUTPUT = list of analytical output
-#' 
-#' M. Lau | May 2013 --------------------------------------------------- enaAll
-#' --- Conduct all ecological network analyses INPUT = network object OUTPUT =
-#' list of analytical output
-#' 
-#' M. Lau | May 2013 ---------------------------------------------------
 #' Conduct All Major ENA
 #' 
 #' Conducts all major ENA with default settings and returns the output as a
@@ -51,6 +30,6 @@ enaAll <- function(x = 'network object'){
               mti = enaMTI(x),
               storage = enaStorage(x),
               structure = enaStructure(x),
-              utility = enaUtility(x,eigen.check=FALSE))
+              utility = enaUtility(x))
   return(out)
 }
